## Feast Cassandra / Astra DB online store plugin

# Deprecation notice

This plugin has been incorporated into the main Feast codebase,
and has been improved since.

This stand-alone distribution is DEPRECATED. Please migrate your Feast
project to using the online store bundled with Feast.
This plugin will not receive any more
updates of any kind.

New issues, and pull requests, to this repo will be _ignored_.

Resources:

- [Feast Cassandra/Astra DB online store](https://docs.feast.dev/reference/online-stores/cassandra)
- [Awesome Astra page](https://awesome-astra.github.io/docs/pages/tools/integration/feast/)

_(if you want to see the previous README for historical reasons, [here it is](archived_README.md))_.
